@@ -3,30 +3,29 @@ from kinopoisk.utils import KinopoiskObject, Manager
 
 class Person(KinopoiskObject):
 
-    name = ''
-    name_original = ''
-    information = ''
+    def set_defaults(self):
+        self.name = ''
+        self.name_original = ''
+        self.information = ''
 
-    year_birth = None
+        self.year_birth = None
 
-    photos = []
+        self.photos = []
 
     def __init__(self, *args, **kwargs):
         super(Person, self).__init__(*args, **kwargs)
+        self.set_defaults()
+
         from sources import PersonLink, PersonMainPage, PersonPhotosPage # import here for successful installing via pip
         self.register_source('link', PersonLink)
         self.register_source('main_page', PersonMainPage)
         self.register_source('photos', PersonPhotosPage)
-        self.posters = self.audience = []
 
         self.set_url('info', '/handler_info.php?obj_type=actor&obj_id=%d')
 
     def __repr__(self):
         return ('<%s (%s), %s>' % (self.name, self.name_original, self.year_birth or '-')).encode('utf-8')
 
-    def get_photos(self):
-        return self.photos
-
 class PersonManager(Manager):
     '''
     Person manager
@@ -45,4 +44,4 @@ class PersonManager(Manager):
             'm_act[find]': query,
         })
 
-Person.objects = PersonManager()
+Person.objects = PersonManager()
\ No newline at end of file
